package com.simuwang.manage.api.contact;

import com.simuwang.base.common.support.MybatisPage;
import com.simuwang.base.pojo.dto.query.CompanyContactQuery;
import com.simuwang.base.pojo.dto.query.CompanyIdQuery;
import com.simuwang.base.pojo.dto.query.ContactQuery;
import com.simuwang.base.pojo.vo.*;
import com.simuwang.logging.SystemLog;
import com.simuwang.manage.service.CompanyContactService;
import com.simuwang.manage.service.ContactInformationService;
import com.smppw.common.pojo.ResultVo;
import com.smppw.common.pojo.enums.status.ResultCode;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;


@SystemLog("公司管理")
@RestController
@RequestMapping("/v1/contact")
public class CompanyContactController {
    @Autowired
    private CompanyContactService companyContactService;

    @Autowired
    private ContactInformationService contactInformationService;

    private static final Logger logger = LoggerFactory.getLogger(CompanyContactController.class);
    /**
     * 保存对接信息
     * @param companyContactInfoVO
     * @return
     */
    @SystemLog(value = "保存公司对接信息", type = SystemLog.Type.INSERT)
    @RequestMapping("save-company-contact")
    public ResultVo saveCompanyContactInfo(@RequestBody CompanyContactInfoVO companyContactInfoVO){
        ResultVo vo = new ResultVo(ResultCode.SAVE_SUCCESS.getCode());
        try{
            vo = companyContactService.saveCompanyContactInfo(companyContactInfoVO);
        }catch (Exception e){
            logger.error(e.getMessage(),e);
            vo.setMsg("保存失败");
            vo.setData(false);
            vo.setCode(ResultCode.SAVE_FAILED.getCode());
        }
        return vo;
    }

    /**
     * 保存联系人信息
     * @param contactInformationVO
     * @return
     */
    @SystemLog(value = "保存联系人信息", type = SystemLog.Type.INSERT)
    @RequestMapping("save-contact-info")
    public ResultVo saveContactInformation(@RequestBody List<ContactInformationVO> contactInformationVO){
        ResultVo vo = new ResultVo(ResultCode.SAVE_SUCCESS.getCode());
        try{
            vo = contactInformationService.saveContactInformation(contactInformationVO);
        }catch (Exception e){
            logger.error(e.getMessage(),e);
            vo.setData(false);
            vo.setCode(ResultCode.SAVE_FAILED.getCode());
        }
        return vo;
    }

    /**
     * 查询公司联系人信息
     * @param contactQuery
     * @return
     */
    @SystemLog(value = "查询公司联系人信息", type = SystemLog.Type.INSERT)
    @RequestMapping("select-contact-info")
    public MybatisPage<ContactInformationVO> selectContactInformationList(ContactQuery contactQuery){
        MybatisPage<ContactInformationVO> result = contactInformationService.selectContactInformationList(contactQuery);
        return result;
    }

    /**
     * 根据ID删除对接人信息
     * @param idVO
     * @return
     */
    @SystemLog(value = "删除公司联系人信息", type = SystemLog.Type.DELETE)
    @PostMapping("delete-contact-information")
    public ResultVo deleteById(@RequestBody IdVO idVO){
        ResultVo vo = contactInformationService.deleteById(idVO.getId());
        return vo;
    }


/**
 * 根据ID删除对接人信息
 * @param idVO
 * @return
 */
    @SystemLog(value = "删除公司对接人信息", type = SystemLog.Type.DELETE)
    @PostMapping("delete-company-contact")
    public boolean deleteCompanyContactById(@RequestBody IdVO idVO){
        companyContactService.deleteById(idVO.getId());
        return true;
    }

    /**
     * 查询公司对接信息
     * @param companyContactQuery
     * @return
     */
    @SystemLog(value = "查询公司对接信息", type = SystemLog.Type.INSERT)
        @RequestMapping("select-company-contact")
    public MybatisPage<CompanyContactInfoPageVO> selectCompanyContactInfoList(CompanyContactQuery companyContactQuery){
        MybatisPage<CompanyContactInfoPageVO> result = companyContactService.selectCompanyContactInfoList(companyContactQuery);
        return result;
    }

    /**
     * 查询对接备注信息
     * @param companyIdQuery
     * @return
     */
    @SystemLog(value = "查询对接备注信息", type = SystemLog.Type.INSERT)
    @RequestMapping("select-contact-remark")
    public MybatisPage<CompanyContactPageVO> selectCompanyContactInfoList(CompanyIdQuery companyIdQuery){
        MybatisPage<CompanyContactPageVO> result = companyContactService.selectCompanyContactList(companyIdQuery);
        return result;
    }

    /**
     * 查询对接人明细
     * @param idVO
     * @return
     */
    @SystemLog(value = "查询对接人明细", type = SystemLog.Type.QUERY)
    @RequestMapping("select-company-contact-detail")
    public ResultVo selectCompanyContactDetail(@RequestBody IdVO idVO){
        ResultVo vo = new ResultVo(ResultCode.SAVE_SUCCESS.getCode());
        try{
            vo = companyContactService.selectCompanyContactDetail(idVO);
        }catch (Exception e){
            logger.error(e.getMessage(),e);
            vo.setData(false);
            vo.setCode(ResultCode.SAVE_FAILED.getCode());
        }
        return vo;
    }

    /**
     * 上传对接人信息
     *
     * @param file
     * @return
     */
    @SystemLog(value = "上传对接人信息", type = SystemLog.Type.UPLOAD_OR_IMPORT)
    @PostMapping("upload-comany-contact")
    public ResultVo uploadCompanyContact(@RequestPart(value = "file") MultipartFile file) {
        ResultVo vo = companyContactService.uploadCompanyContact(file);
        return vo;
    }
}
