package com.simuwang.manage.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.simuwang.base.common.support.MybatisPage;
import com.simuwang.base.mapper.daq.EmailTemplateMapper;
import com.simuwang.base.pojo.dos.EmailTemplateDO;
import com.simuwang.base.pojo.dto.query.EmailTemplatePageQuery;
import com.simuwang.base.pojo.vo.EmailTemplateVO;
import com.simuwang.base.pojo.vo.IdListVO;
import com.simuwang.base.pojo.vo.StatusVO;
import com.simuwang.manage.service.EmailTemplateService;
import com.simuwang.shiro.utils.UserUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class EmailTemplateServiceImpl implements EmailTemplateService {
    @Autowired
    private EmailTemplateMapper emailTemplateMapper;

    @Override
    public MybatisPage<EmailTemplateVO> searchEmailTemplateList(EmailTemplatePageQuery emailTemplatePageQuery) {
        List<EmailTemplateDO> emailTemplateDOList = emailTemplateMapper.searchEmailTemplateList(emailTemplatePageQuery);
        List<EmailTemplateVO> emailTemplateVOList = emailTemplateDOList.stream().map(EmailTemplateDO::toVO).collect(Collectors.toUnmodifiableList());
        Long total = emailTemplateMapper.countEmailTemplateList(emailTemplatePageQuery);
        return MybatisPage.of(total, emailTemplateVOList);
    }

    @Override
    public EmailTemplateVO searchEmailTemplate(Integer id) {
        EmailTemplateDO emailTemplateDO = emailTemplateMapper.searchTemplateById(id);
        return emailTemplateDO==null?null:emailTemplateDO.toVO();
    }

    @Override
    public void saveEmailTemplate(EmailTemplateVO emailTemplateVO) {
        EmailTemplateDO emailTemplateDO = new EmailTemplateDO();
        BeanUtil.copyProperties(emailTemplateVO, emailTemplateDO);
        emailTemplateDO.setIsvalid(1);
        Integer userId = UserUtils.getLoginUser().getUserId();
        emailTemplateDO.setCreatorId(userId);
        emailTemplateDO.setUpdaterId(userId);
        emailTemplateDO.setCreateTime(new Date());
        emailTemplateDO.setUpdateTime(new Date());
        emailTemplateMapper.insertOrUpdate(emailTemplateDO);
    }

    @Override
    public boolean checkEmailTemplateUnique(EmailTemplateVO emailTemplateVO) {
        String templateCode = emailTemplateVO.getTemplateCode();
        EmailTemplateDO emailTemplateDO = emailTemplateMapper.selectByCode(templateCode);
        if(emailTemplateDO==null){
            return true;
        }
        if(emailTemplateVO.getId() != null && emailTemplateDO.getId().intValue() != emailTemplateVO.getId().intValue()){
            return false;
        }
        return true;
    }

    @Override
    public void controlEmailTemplateConfig(StatusVO statusVO) {
        Integer userId = UserUtils.getLoginUser().getUserId();
        emailTemplateMapper.updateOpenStatus(statusVO,userId);
    }

    @Override
    public void deleteEmailTemplateList(IdListVO idListVO) {
        Integer userId = UserUtils.getLoginUser().getUserId();
        List<Integer> idList = idListVO.getIdList();
        emailTemplateMapper.deleteTemplateList(idList,userId);
    }
}
